use clap::Parser;

use sudoku::ksudoku::load_ksudoku;
use sudoku::sudoku::*;

// Command line arguments - via clap

#[derive(Parser)]
struct Cli {
    /// The path to the file to
    #[arg(short = 'f', long = "file", value_name = "FILENAME")]
    filename: Option<std::path::PathBuf>,

    /// Make a sudoku
    #[arg(short = 'm', long = "make", action = clap::ArgAction::SetTrue)]
    make: Option<bool>,
}

fn main() {
    let args = Cli::parse();
    let mut s = Sudoku::new();

    if args.make.is_some() {
        s.make();
        s.display();
        s.display_possible();
    } else {
        if args.filename.is_some() {
            let puzzle = load_ksudoku(args.filename.unwrap()).unwrap();

            // Ksudoku is stored TLD.
            s.load_from_tld('b', '_', puzzle.as_str());
            s.display();
            s.display_possible();

            while s.solve() {
                println!("Try it again...");
                s.display();
                s.display_possible();
            }
        }
    }
}
